//--------LICENSE_START--------
//
// Copyright (C) 2020,2021,2022 Institut de Robòtica i Informàtica Industrial, CSIC-UPC.
// Authors: Joan Solà Ortega (jsola@iri.upc.edu)
// All rights reserved.
//
// This file is part of WOLF
// WOLF is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//--------LICENSE_END--------
#ifndef CAPTURE_GNSS_H_
#define CAPTURE_GNSS_H_

//Wolf includes
#include "gnss/feature/feature_gnss_fix.h"
#include "core/capture/capture_base.h"

//std includes
#include "gnss_utils/snapshot.h"

namespace wolf {

WOLF_PTR_TYPEDEFS(CaptureGnss);

//class CaptureGnss
class CaptureGnss : public CaptureBase
{
    protected:
        GnssUtils::SnapshotPtr snapshot_; ///< observation and navigation data

    public:
      CaptureGnss(const TimeStamp& _ts, SensorBasePtr _sensor_ptr, GnssUtils::SnapshotPtr _snapshot);
      ~CaptureGnss() override;

      GnssUtils::SnapshotConstPtr getSnapshot() const;
      GnssUtils::SnapshotPtr getSnapshot();
      GnssUtils::ObservationsConstPtr getObservations() const;
      GnssUtils::ObservationsPtr getObservations();
      GnssUtils::NavigationConstPtr getNavigation() const;
      GnssUtils::NavigationPtr getNavigation();
      const GnssUtils::Satellites& getSatellites() const;
      GnssUtils::Satellites& getSatellites();

};

inline GnssUtils::SnapshotConstPtr CaptureGnss::getSnapshot() const
{
  return snapshot_;
}

inline GnssUtils::SnapshotPtr CaptureGnss::getSnapshot()
{
  return snapshot_;
}

inline GnssUtils::ObservationsConstPtr CaptureGnss::getObservations() const
{
  return snapshot_->getObservations();
}

inline GnssUtils::ObservationsPtr CaptureGnss::getObservations()
{
  return snapshot_->getObservations();
}

inline GnssUtils::NavigationConstPtr CaptureGnss::getNavigation() const
{
  return snapshot_->getNavigation();
}

inline GnssUtils::NavigationPtr CaptureGnss::getNavigation()
{
  return snapshot_->getNavigation();
}

inline GnssUtils::Satellites& CaptureGnss::getSatellites()
{
  return snapshot_->getSatellites();
}

inline const GnssUtils::Satellites& CaptureGnss::getSatellites() const
{
  return snapshot_->getSatellites();
}

} //namespace wolf
#endif
